//This script was created to serve as an example in using CStExe to compile C# scripts to a Windows
//executable launcher.  When compiled this example should launch a batch file, exec.bat, that
//will, in turn, open a text file in the systems default text reader, probably Notepad.

using System;
using System.Collections.Generic;
using System.Text;
using System.Diagnostics;
using System.IO;

//When compiling with CStExe the Main Class field should be populated with Example.ExampleClass
//When making your own scripts the namespace and class names can be whatever you like
namespace Example
{
	class ExampleClass
	{

	   static void Main(string[] args)
	   {
		//Create a new process to launch, in this case a batch file.
		//The argument for ProcessStartInfo is the command to be executed on the console
		//In this case we assume the batch file is in the same directory as the executable
		//If the batch file is in a subdirectory, for instance a bin directory, you could change
		//the argument here to read Path.Combine(Environment.CurrentDirectory, "bin" + Path.DirectorySeparatorChar + "exec.bat")
		//For more complex tasks you could supply both a command and arguments to ProcessStartInfo
		//In such a case ProcessStartInfo takes in two arguments, the first being the command and the second
		//being the arguments.  Personally I prefer to just launch a batch file which can include any
		//commands and arguments, that way I can just edit the batch file if need be without having to
		//re-compile the executable.
		Process prc = new Process();
		prc.StartInfo = new ProcessStartInfo(Path.Combine(Environment.CurrentDirectory, "exec.bat"));
		
		//Here we set several options to hide the console of what will be the newly created process
		prc.StartInfo.UseShellExecute = false;
		prc.StartInfo.WindowStyle = ProcessWindowStyle.Hidden;
		prc.StartInfo.CreateNoWindow = true;
		
		//The console for the new process is hidden so we redirect its output to this executable's console
		prc.StartInfo.RedirectStandardOutput = true;
		
		prc.Start(); //Start the new process
		Console.WriteLine("Starting example executable..."); //Unnecessary, but can be useful for debugging and such
		
		//Setup a reader to get the output from our new process so we can redirect it to
		//the executable's console
		StreamReader sr = prc.StandardOutput;
		
		//Read each output line from the process and print it to the executable's console
		while (prc.HasExited == false)
		{
			string output = sr.ReadLine();
			if (output != null) {
				if (output.Length > 0) {
					Console.WriteLine(output);
				}
			}
		}

		Console.WriteLine("Example executable exited successfully.  Have a nice day :)"); //Unnecessary, but useful for debugging or being friendly :)
	   }
	}
}
